/* (c) Magnus Auvinen. See licence.txt in the root of the distribution for more information. */
/* If you are missing that file, acquire a complete release at teeworlds.com.                */
#include <engine/shared/config.h>
#include <engine/graphics.h>
#include <engine/textrender.h>
#include <game/generated/protocol.h>
#include <game/generated/client_data.h>

#include <game/client/gameclient.h>

#include <game/client/components/motd.h>
#include <game/client/components/scoreboard.h>

#include "broadcast.h"
	
void CBroadcast::OnReset()
{
	m_BroadcastTime = 0;
}

void CBroadcast::OnRender()
{
	if(m_pClient->m_pScoreboard->Active() || m_pClient->m_pMotd->IsActive())
		return;

	Graphics()->MapScreen(0, 0, 300*Graphics()->ScreenAspect(), 300);
		
	if(time_get() < m_BroadcastTime)
	{
		CTextCursor Cursor;
		if(!g_Config.m_ClRace || str_find_nocase(m_aBroadcastText, "Current time: ") == NULL)			
		{
			int txtSize = (int)(12.f*(float)g_Config.m_ClBroadcastSize/100.f);
			TextRender()->SetCursor(&Cursor, m_BroadcastRenderOffset, 40.0f, txtSize, TEXTFLAG_RENDER|TEXTFLAG_STOP_AT_END);
			Cursor.m_LineWidth = 300*Graphics()->ScreenAspect()-m_BroadcastRenderOffset;
			TextRender()->TextEx(&Cursor, m_aBroadcastText, -1);
		}
		else // Gamer: broadcasting a RACE time
		{
			char Str[32];
			int i = 0, j, txtsize = g_Config.m_ClRaceTextsize/10;
			char* fullText = m_aBroadcastText + str_length("Current Time: "); // Contains everything from "x min"
			const char* CheckPt = str_find_nocase(fullText, "Checkpoint | Diff : "); // Contains everything from "Checkpoint"
			char Minutes[5];
			
			while(fullText[i] != 'm')
			{
				Str[i] = fullText[i];
				i++;
			}
			Str[i-1] = '\0';
			str_copy(Minutes, Str, sizeof(Minutes));
			
			
			i+= str_length("min ");
			j = i;
			while(fullText[i] != 's')
			{
				Str[i-j] = fullText[i];
				i++;
			}
			Str[i-j-1] = '\0';
			char* Seconds = Str;
			
			char Text[512];
			str_format(Text, sizeof(Text), "%s:%s%s", Minutes, Seconds[1] == '\0' ? "0" : "", Seconds);	
			float Whole = 300*Graphics()->ScreenAspect();
			float w = TextRender()->TextWidth(0, txtsize, Text, -1);
			float Pos = Whole/2.0f - w/2 + 12/2;
	
			TextRender()->TextColor(0.76f, 0.47f, 0.76f, 1.0f);
			TextRender()->Text(0, Pos, 15, txtsize, Text, -1);
			
			if(CheckPt != NULL)
			{
				const char* CheckPtDifftime = CheckPt + str_length("Checkpoint | Diff : ");
					
				if(str_find_nocase(fullText, "Checkpoint | Diff : -"))
					TextRender()->TextColor(0.3f, 1, 0.3f, 1);
				if(str_find_nocase(fullText, "Checkpoint | Diff : +"))
					TextRender()->TextColor(1, 0.2f, 0.2f, 1);
				
				w = TextRender()->TextWidth(0, (txtsize*12)/10, CheckPtDifftime, -1);
				float Pos2 = Whole/2.0f - w/2;
				TextRender()->Text(0, Pos2, 40, (txtsize*12)/10, CheckPtDifftime, -1);
			}
			
			Graphics()->TextureSet(g_pData->m_aImages[IMAGE_RACE].m_Id);
			Graphics()->QuadsBegin();
			RenderTools()->SelectSprite(SPRITE_CLOCK);
	
			IGraphics::CQuadItem QuadItem(Pos - (txtsize*12)/10, 15 + txtsize/5, txtsize, txtsize);
			Graphics()->QuadsDrawTL(&QuadItem, 1);
			
			Graphics()->QuadsEnd();
			TextRender()->TextColor(1.0f, 1.0f, 1.0f, 1.0f);
		}
	}
}

void CBroadcast::OnMessage(int MsgType, void *pRawMsg)
{
	if(MsgType == NETMSGTYPE_SV_BROADCAST)
	{
		CNetMsg_Sv_Broadcast *pMsg = (CNetMsg_Sv_Broadcast *)pRawMsg;
		str_copy(m_aBroadcastText, pMsg->m_pMessage, sizeof(m_aBroadcastText));
		CTextCursor Cursor;
		TextRender()->SetCursor(&Cursor, 0, 0, 12.0f, TEXTFLAG_STOP_AT_END);
		Cursor.m_LineWidth = 300*Graphics()->ScreenAspect();
		TextRender()->TextEx(&Cursor, m_aBroadcastText, -1);
		m_BroadcastRenderOffset = 150*Graphics()->ScreenAspect()-Cursor.m_X/2;
		m_BroadcastTime = time_get()+time_freq()*10;
	}
}

