#include <engine/shared/config.h>
#include <engine/textrender.h>
#include <engine/graphics.h>

#include <game/generated/client_data.h>

#include <game/version.h>
#include <game/client/ui.h>
#include <game/client/render.h>
#include <game/client/gameclient.h>
#include <game/client/animstate.h>

#include <fstream> // Loading stats
#include <time.h> // Random

#include "binds.h"
#include "menus.h"
#include "skins.h"
#include "items.h"
#include "sounds.h"

void CMenus::RenderSettingsGamer(CUIRect MainView)
{
	CUIRect Button, Tabbar;
	// char buf[64];
	
	static int s_SettingsPage = 0;
	
	// Tabs (Teecomp pattern)
	MainView.HSplitTop(24.0f, &Tabbar, &MainView);

	const char *Tabs[] = {"General", "Stats", "Credits"};
	int NumTabs = (int)(sizeof(Tabs)/sizeof(*Tabs));

	for(int i=0; i<NumTabs; i++)
	{
		Tabbar.VSplitLeft(10.0f, &Button, &Tabbar);
		Tabbar.VSplitLeft(80.0f, &Button, &Tabbar);
		
		// if(ui_do_button(tabs[i], tabs[i], settings_page == i, &button, ui_draw_menu_tab_button, &Corners))
		
		static int s_Buttons[3] = {0};
		if (DoButton_MenuTab(&s_Buttons[i], Tabs[i], s_SettingsPage == i, &Button, CUI::CORNER_ALL))
			s_SettingsPage = i;
	}
	
	// ui_hsplit_t(&main_view, 10.0f, &button, &main_view);
	MainView.Margin(10.0f, &MainView);
	
	if(s_SettingsPage == 0)
		RenderSettingsGamerGeneral(MainView);
	else if(s_SettingsPage == 1)
		RenderSettingsGamerStats(MainView);
	else if(s_SettingsPage == 2)
		RenderSettingsGamerCredits(MainView);
}
void CMenus::RenderSettingsGamerGeneral(CUIRect MainView)
{
	CUIRect Button, LeftView, RightView;
	char aBuf[512];
	
	static int s_FirstTime = 1;
	if(s_FirstTime)
	{
		srand(time(NULL));
		s_FirstTime = 0;
	}
	
	MainView.VSplitLeft(MainView.w/2, &LeftView, &RightView);
	
	LeftView.HSplitTop(20.0f, &Button, &LeftView);
	
	UI()->DoLabel(&Button, Localize("Health and Ammo"), 14.0f, -1);
	LeftView.HSplitTop(20.0f, &Button, &LeftView);
	if(DoButton_CheckBox(&g_Config.m_ClGhud, Localize("Gamer HUD"), g_Config.m_ClGhud, &Button))
		g_Config.m_ClGhud ^= 1;
		
	LeftView.HSplitTop(20.0f, &Button, &LeftView);
	if(DoButton_CheckBox(&g_Config.m_ClNoHud, Localize("Disable HUD"), g_Config.m_ClNoHud, &Button))
		g_Config.m_ClNoHud ^= 1;
		
	LeftView.HSplitTop(20.0f, &Button, &LeftView);
	LeftView.HSplitTop(20.0f, &Button, &LeftView);
	if(DoButton_CheckBox(&g_Config.m_GfxHealthBar, Localize("Display healthbar"), g_Config.m_GfxHealthBar, &Button))
		g_Config.m_GfxHealthBar ^= 1;
	
	LeftView.HSplitTop(20.0f, &Button, &LeftView);
	if(DoButton_CheckBox(&g_Config.m_ClGcolor, Localize("Use Gamer colors"), g_Config.m_ClGcolor, &Button))
		g_Config.m_ClGcolor ^= 1;
		
		
	LeftView.HSplitTop(20.0f, &Button, &LeftView);
	LeftView.HSplitTop(20.0f, &Button, &LeftView);
	UI()->DoLabel(&Button, Localize("Sounds"), 14.0f, -1);
	LeftView.HSplitTop(20.0f, &Button, &LeftView);
	if(DoButton_CheckBox(&g_Config.m_ClGSound, Localize("Gamer sounds"), g_Config.m_ClGSound, &Button))
		g_Config.m_ClGSound ^= 1;
		
	Button.VSplitLeft(145.0f, 0, &Button);
	Button.VSplitLeft(140.0f, &Button, 0);
	static int s_TestButton = 0;
	if(DoButton_Menu(&s_TestButton, "Test one!", 0, &Button))
	{
		int sounds[11] = {SOUND_SPREE_HUMILIATION, SOUND_SPREE_KILLING, SOUND_SPREE_RAMPAGE, SOUND_SPREE_DOMINATING, SOUND_SPREE_UNSTOPPABLE, SOUND_SPREE_GODLIKE,
		SOUND_SPREE_WICKEDSICK, SOUND_SPREE_PREPARETOFIGHT, SOUND_SPREE_PREPARETOKILL, SOUND_SPREE_HOLYSHIT, SOUND_SPREE_FIRSTBLOOD};
		m_pClient->m_pSounds->Play(CSounds::CHN_GUI, sounds[rand()%11], 0, vec2(0,0));
	}	
	
	LeftView.HSplitTop(20.0f, &Button, &LeftView);
	LeftView.HSplitTop(20.0f, &Button, &LeftView);
	UI()->DoLabel(&Button, Localize("Extras"), 14.0f, -1);
	
	LeftView.HSplitTop(20.0f, &Button, &LeftView);
	{
		static float Offset = 0.0f;
		static int s_PlusButton = 0;
		static int s_MinusButton = 0;
		bool Minus, Plus;
		
		str_format(aBuf, sizeof(aBuf), "%d", g_Config.m_ClBroadcastSize);
		UI()->DoLabel(&Button, Localize("Broadcast size (%)"), 12.0f, -1);
		Button.VSplitLeft(120.0f, 0, &Button);
		Button.VSplitLeft(40.0f, &Button, 0);
		DoEditBox(&g_Config.m_ClBroadcastSize, &Button, aBuf, sizeof(aBuf), 14.0f, &Offset);
		
		g_Config.m_ClBroadcastSize =  max(1, str_toint(aBuf));
		
		Button.VSplitLeft(45.0f, 0, &Button);
		Button.VSplitLeft(15.0f, &Button, 0);
		Plus = DoButton_Menu(&s_PlusButton, "+", 0, &Button);
		
		Button.VSplitLeft(16.0f, 0, &Button);
		Button.VSplitLeft(15.0f, &Button, 0);
		Minus = DoButton_Menu(&s_MinusButton, "-", 0, &Button);
		
		g_Config.m_ClBroadcastSize += (int)Plus*10 - (int)Minus*10;
	}
	
	
	LeftView.HSplitTop(20.0f, &Button, &LeftView);
	LeftView.HSplitTop(20.0f, &Button, &LeftView);
	if(DoButton_CheckBox(&g_Config.m_GfxFullClear, Localize("Only show the game tiles"), g_Config.m_GfxFullClear, &Button))
		g_Config.m_GfxFullClear ^= 1;
		
	LeftView.HSplitTop(20.0f, &Button, &LeftView);
	if(DoButton_CheckBox(&g_Config.m_ClSendClientInfo, Localize("Be marked as Gamer user in other Gamers' scoreboard"), g_Config.m_ClSendClientInfo, &Button))
		g_Config.m_ClSendClientInfo ^= 1;
		
	LeftView.HSplitTop(20.0f, &Button, &LeftView);
	if(DoButton_CheckBox(&g_Config.m_ClShowapm, Localize("Show ingame APM counter"), g_Config.m_ClShowapm, &Button))
		g_Config.m_ClShowapm ^= 1;
		
	LeftView.HSplitTop(20.0f, &Button, &LeftView);
	if(DoButton_CheckBox(&g_Config.m_UiHighlighGametype, Localize("Color gametypes in server browser"), g_Config.m_UiHighlighGametype, &Button))
		g_Config.m_UiHighlighGametype ^= 1;
		
	
	// Right View	
	RightView.HSplitTop(20.0f, &Button, &RightView);
	UI()->DoLabel(&Button, Localize("Fake"), 14.0f, -1);
	RightView.HSplitTop(20.0f, &Button, &RightView);
	if(DoButton_CheckBox(&g_Config.m_UiFakeOption, Localize("Display one-click fake button in server browser"), g_Config.m_UiFakeOption, &Button))
		g_Config.m_UiFakeOption ^= 1;
	
	RightView.HSplitTop(20.0f, &Button, &RightView);
	if(DoButton_CheckBox(&g_Config.m_ClFake, Localize("Use fake"), g_Config.m_ClFake, &Button))
	{
		char name[32];

		g_Config.m_ClFake ^= 1;
		str_copy(name, g_Config.m_PlayerName, sizeof(name));
		str_copy(g_Config.m_PlayerName, g_Config.m_PlayerSecondName, sizeof(g_Config.m_PlayerName));
		str_copy(g_Config.m_PlayerSecondName, name, sizeof(g_Config.m_PlayerSecondName));
		
		str_copy(name, g_Config.m_PlayerSkin, sizeof(name));
		str_copy(g_Config.m_PlayerSkin, g_Config.m_PlayerSecondSkin, sizeof(g_Config.m_PlayerSkin));
		str_copy(g_Config.m_PlayerSecondSkin, name, sizeof(g_Config.m_PlayerSecondSkin));
		
		str_copy(name, g_Config.m_PlayerClan, sizeof(name));
		str_copy(g_Config.m_PlayerClan, g_Config.m_PlayerSecondClan, sizeof(g_Config.m_PlayerClan));
		str_copy(g_Config.m_PlayerSecondClan, name, sizeof(g_Config.m_PlayerSecondClan));
	}
	char str[50];
	str_format(str, sizeof(str), "(Used: %s|%s)", g_Config.m_PlayerClan, g_Config.m_PlayerName);
	Button.x += 120.0f;
	UI()->DoLabel(&Button, str, 12.0f, -1);
	
	RightView.HSplitTop(20.0f, &Button, &RightView);
	RightView.HSplitTop(20.0f, &Button, &RightView);
	UI()->DoLabel(&Button, Localize("Chat"), 14.0f, -1);
	RightView.HSplitTop(20.0f, &Button, &RightView);
	if(DoButton_CheckBox(&g_Config.m_ClChatSound, Localize("Chat sounds"), g_Config.m_ClChatSound, &Button))
		g_Config.m_ClChatSound ^= 1;
		
	RightView.HSplitTop(20.0f, &Button, &RightView);
	if(DoButton_CheckBox(&g_Config.m_ClArrows, Localize("Use arrows in place of chat"), g_Config.m_ClArrows, &Button))
		g_Config.m_ClArrows ^= 1;
		
	RightView.HSplitTop(20.0f, &Button, &RightView);
	if(DoButton_CheckBox(&g_Config.m_ClNoCustomForArrows, Localize("Do not use custom team colors for arrows"), g_Config.m_ClNoCustomForArrows, &Button))
		g_Config.m_ClNoCustomForArrows ^= 1;
		
	RightView.HSplitTop(20.0f, &Button, &RightView);
	if(DoButton_CheckBox(&g_Config.m_ClChatShinyHighligh, Localize("Shiny letters when being highlighed"), g_Config.m_ClChatShinyHighligh, &Button))
		g_Config.m_ClChatShinyHighligh ^= 1;

	RightView.HSplitTop(20.0f, &Button, &RightView);
	{		
		static float Offset = 0.0f;
		static int s_PlusButton = 0;
		static int s_MinusButton = 0;
		bool Minus, Plus;
		
		str_format(aBuf, sizeof(aBuf), "%d", g_Config.m_ClTextSize);
		UI()->DoLabel(&Button, Localize("Chat size (%)"), 12.0f, -1);
		Button.VSplitLeft(90.0f, 0, &Button);
		Button.VSplitLeft(40.0f, &Button, 0);
		DoEditBox(&g_Config.m_ClTextSize, &Button, aBuf, sizeof(aBuf), 14.0f, &Offset);
		
		Button.VSplitLeft(45.0f, 0, &Button);
		Button.VSplitLeft(15.0f, &Button, 0);
		Plus = DoButton_Menu(&s_PlusButton, "+", 0, &Button);
		
		Button.VSplitLeft(16.0f, 0, &Button);
		Button.VSplitLeft(15.0f, &Button, 0);
		Minus = DoButton_Menu(&s_MinusButton, "-", 0, &Button);
			
		Button.VSplitLeft(45.0f, 0, &Button);
		UI()->DoLabel(&Button, Localize("Dune says : Test !"), 12.0f*clamp(g_Config.m_ClTextSize, 50, 200)/100.0f, -1);
		g_Config.m_ClTextSize =  max(1, str_toint(aBuf));
		
		if(Plus)
			g_Config.m_ClTextSize += 10;
		else if(Minus)
			g_Config.m_ClTextSize -= 10;
	}
}

#define PRINT_STATS(str, var) \
	MainView.HSplitTop(20.0f, &Button, &MainView);\
	UI()->DoLabel(&Button, Localize(str), 14.0f, -1);\
	Button.VSplitLeft(115.0f, 0, &Button);\
	str_format(buf, sizeof(buf), "%d", var);\
	UI()->DoLabel(&Button, buf, 12.0f, -1);\

#define PRINT_STATS_MED(str, var, games) \
	MainView.HSplitTop(20.0f, &Button, &MainView);\
	UI()->DoLabel(&Button, Localize(str), 13.0f, -1);\
	Button.VSplitLeft(115.0f, 0, &Button);\
	str_format(buf, sizeof(buf), "%.2f", (float)var/(float)games);\
	UI()->DoLabel(&Button, buf, 12.0f, -1);\

#define PRINT_STATS_STR(str, str2, str3) \
	MainView.HSplitTop(20.0f, &Button, &MainView);\
	UI()->DoLabel(&Button, Localize(str), 14.0f, -1);\
	Button.VSplitLeft(115.0f, 0, &Button);\
	UI()->DoLabel(&Button, str2, 12.0f, -1);\
	Button.VSplitLeft(120.0f, 0, &Button);\
	UI()->DoLabel(&Button, str3, 12.0f, -1);\


void CMenus::RenderSettingsGamerStats(CUIRect MainView)
{
	CUIRect Button, ResetButton, RefreshButton, Footer;
	static PersonalStats stats;
	static int IsLoaded = NOT_LOADED;
	
	if(!IsLoaded)
	{
		char Path[512];
		FILE* File;
		
#if defined(CONF_FAMILY_WINDOWS)
		str_format(Path, sizeof(Path), "%s\\stats.cfg", ClientUserDirectory());
#else
		str_format(Path, sizeof(Path), "%s/stats.cfg", ClientUserDirectory());
#endif
		
		File = fopen(Path, "r");
		if(File)
		{
			int* StatsVar[] = {&stats.games, &stats.frags_with[0], &stats.frags_with[1], &stats.frags_with[2], &stats.frags_with[3], &stats.frags_with[4], &stats.frags_with[5],
			&stats.deaths_from[0], &stats.deaths_from[1], &stats.deaths_from[2], &stats.deaths_from[3], &stats.deaths_from[4], &stats.deaths_from[5], &stats.frags, &stats.deaths,
			&stats.suicides, &stats.flag_grabs, &stats.flag_captures, &stats.carriers_killed, &stats.kills_carrying, &stats.deaths_carrying, &stats.won,};
		
			int NumStatsVar = 22, i;
			
			for(i = 0; i < NumStatsVar; i++)
			{
				if(!fscanf(File, "%d", StatsVar[i]))
				{
					dbg_msg("client/stats", "file is corrupted, cannnot continue reading");
					break;
				}
			}
			
			fclose(File);
			
			IsLoaded = (i == NumStatsVar) ? LOADED : FAILED_LOADING;
		}
		else
			IsLoaded = FAILED_LOADING;
	}
	
	MainView.HSplitTop(3.0f, &MainView, &Button);
	
	UI()->DoLabel(&Button, Localize("Personal statistics"), 20.0f, -1);
	
	MainView.HSplitTop(10.0f, &Button, &MainView);
	MainView.HSplitTop(20.0f, &Button, &MainView);
	
	MainView.HSplitTop(20.0f, &Button, &MainView);
	if(DoButton_CheckBox(&g_Config.m_ClRegisterStats, Localize("Register stats"), g_Config.m_ClRegisterStats, &Button))
		g_Config.m_ClRegisterStats ^= 1;
		
	MainView.HSplitTop(20.0f, &Button, &MainView);
	if(DoButton_CheckBox(&g_Config.m_ClRegisterStatsPure, Localize("Only register stats from pure games"), g_Config.m_ClRegisterStatsPure, &Button))
		g_Config.m_ClRegisterStatsPure ^= 1;
	
	MainView.HSplitTop(20.0f, &Button, &MainView);
	
	if(IsLoaded == FAILED_LOADING)
	{
		UI()->DoLabel(&Button, Localize("Cannot load stats: you have never finished a game."), 14.0f, -1);
	}
	else
	{		
		char buf[256];
		char buf2[256];
		PRINT_STATS("Games:", stats.games)
		
		if(stats.games)
			str_format(buf, sizeof(buf), "%.1f%%", 100*(float)stats.won/(float)stats.games);
		else str_format(buf, sizeof(buf), "N/A");
		PRINT_STATS_STR("Won:", buf, "")
		MainView.HSplitTop(10.0f, &Button, &MainView);

		if(stats.frags > (stats.deaths))
			TextRender()->TextColor(0,1,0,1);
		else if(stats.frags < (stats.deaths))
			TextRender()->TextColor(1,0,0,1);
		else
			TextRender()->TextColor(1,1,0,1);
		if(stats.deaths)
			str_format(buf, sizeof(buf), "%.2f (%d/%d)", (float)stats.frags/(float)(stats.deaths), stats.frags, stats.deaths);
		else str_format(buf, sizeof(buf), "N/A (%d/%d)", stats.frags, stats.deaths);
		PRINT_STATS_STR("Ratio:", buf, "")
		TextRender()->TextColor(1,1,1,1);
		
		MainView.HSplitTop(10.0f, &Button, &MainView);
		MainView.HSplitTop(20.0f, &Button, &MainView);
		UI()->DoLabel(&Button, Localize("Per game:"), 16.0f, -1);
		if(stats.games)
		{
			PRINT_STATS_MED("Suicides:", stats.suicides, stats.games)
			PRINT_STATS_MED("Flag grabs:", stats.flag_grabs, stats.games)
			PRINT_STATS_MED("Carriers killed:", stats.carriers_killed, stats.games)
			PRINT_STATS_MED("Kills carrying:", stats.kills_carrying, stats.games)
			PRINT_STATS_MED("Deaths carrying:", stats.deaths_carrying, stats.games)
		}
		else
		{
			PRINT_STATS("Suicides:", stats.suicides)
			PRINT_STATS("Flag grabs:", stats.flag_grabs)
			PRINT_STATS("Carriers killed:", stats.carriers_killed)
			PRINT_STATS("Kills carrying:", stats.kills_carrying)
			PRINT_STATS("Deaths carrying:", stats.deaths_carrying)
		}
		
		MainView.HSplitTop(20.0f, &Button, &MainView);
		MainView.HSplitTop(15.0f, &Button, &MainView);
		
		const char* WeaponsStr[6] = {"      Hammer", "      Pistol", "      Shotgun", "      Rocket", "      Rifle", "      Ninja"};
		Button.VSplitLeft(110.0f, 0, &Button); UI()->DoLabel(&Button, Localize("Frags with:"), 14.0f, -1);
		Button.VSplitLeft(120.0f, 0, &Button); UI()->DoLabel(&Button, Localize("Deaths from:"), 14.0f, -1);
		
		for(int i = 0; i < 6; i++)
		{
			if(!stats.frags_with[i] && !stats.deaths_from[i]) // Unused weapon
				continue;
				
			if(stats.frags)
			{
				if(stats.frags_with[i])
					str_format(buf, sizeof(buf), "%s%.1f%%", 10*stats.frags_with[i] < stats.frags ? "0" : "",
						(float)(100*stats.frags_with[i])/(float)stats.frags);
				else
					str_copy(buf, "    -", sizeof(buf));
			}
			else str_copy(buf, "N/A", sizeof(buf));
			if(stats.deaths)
			{
				if(stats.deaths_from[i])
					str_format(buf2, sizeof(buf2), "%s%.1f%%", 10*stats.deaths_from[i] < stats.deaths ? "0" : "",
						(float)(100*stats.deaths_from[i])/(float)stats.deaths);
				else
					str_copy(buf2, "    -", sizeof(buf2));
			}
			else str_copy(buf2, "N/A", sizeof(buf2));
			
			PRINT_STATS_STR(WeaponsStr[i], buf, buf2)
			
			Graphics()->TextureSet(g_pData->m_aImages[IMAGE_GAME].m_Id);
			Graphics()->QuadsBegin();
			RenderTools()->SelectSprite(g_pData->m_Weapons.m_aId[i].m_pSpriteBody, 0);
			if(i == 5)
				RenderTools()->DrawSprite(20.0f, Button.y+10.0f, 27.0f);
			else
				RenderTools()->DrawSprite(25.0f, Button.y+10.0f, 27.0f);
			Graphics()->QuadsEnd();
		}
	}

	// draw footers	
	/*MainView.HSplitBottom(20.0f, &MainView, &Footer);
	Footer.HSplitTop(10.0f, &Button, &Footer);
	
	Button.HSplitTop(20.0f, &RefreshButton, &Footer);
	Button.HSplitTop(20.0f, &ResetButton, &Footer);*/
	MainView.HSplitTop(15.0f, &Button, &MainView);
	MainView.HSplitTop(20.0f, &Button, &MainView);
	
	Button.HSplitTop(20.0f, &RefreshButton, &MainView);
	Button.HSplitTop(20.0f, &ResetButton, &MainView);
	// MainView.HSplitBottom(20.0f, &MainView, &RefreshButton);
	// MainView.HSplitBottom(20.0f, &MainView, &ResetButton);
	
	RefreshButton.VSplitLeft(20.0f, 0, &RefreshButton);
	RefreshButton.VSplitLeft(150.0f, &RefreshButton, 0);
	static int s_Refresh = 0;
	if(DoButton_Menu(&s_Refresh, Localize("Refresh"), 0, &RefreshButton))
	{
		IsLoaded = NOT_LOADED;
	}

	ResetButton.VSplitLeft(200.0f, 0, &ResetButton);
	ResetButton.VSplitLeft(150.0f, &ResetButton, 0);
	static int s_Reset = 0;
	if(DoButton_Menu(&s_Reset, Localize("Reset stats"), 0, &ResetButton))
	{
		char Path[512];
		FILE* File;
		
#if defined(CONF_FAMILY_WINDOWS)
		str_format(Path, sizeof(Path), "%s\\stats.cfg", ClientUserDirectory());
#else
		str_format(Path, sizeof(Path), "%s/stats.cfg", ClientUserDirectory());
#endif

		File = fopen(Path, "w+");
		if(!File)
			return;
		for(int j = 0; j < 22; j++)
			fputs("0\n", File);
		fclose(File);
		IsLoaded = NOT_LOADED; // We will refresh the stats the next time
	}
	
	
	/*
	MainView.HSplitBottom(40.0f, &MainView, &Button);
	UI()->DoLabel(&Button, "Stats tab incoming in 4.1 <3", 10.0f, 0);
	*/
}

#define CREDITS_HEADER(s) 	MainView.HSplitTop(20.0f, &Button, &MainView);\
	MainView.HSplitTop(20.0f, &Button, &MainView);\
	UI()->DoLabel(&Button, Localize(s), 14.0f, 0);
	
#define CREDITS_LINE(s)MainView.HSplitTop(20.0f, &Button, &MainView);\
	UI()->DoLabel(&Button, Localize(s), 12.0f, 0);


void CMenus::RenderSettingsGamerCredits(CUIRect MainView)
{
	CUIRect Button;
	
	MainView.HSplitTop(52.0f, &Button, &MainView);
	UI()->DoLabel(&Button, "Gamer", 48.0f, 0);
	
	CREDITS_HEADER("Programmation")
	CREDITS_LINE("Dunedune")

	CREDITS_HEADER("Patched separated projects")
	CREDITS_LINE("Spl0k (Teecomp)")
	CREDITS_LINE("Sushi Tee (Race)")
	CREDITS_LINE("EdgeCruSher (Teecomp++)")
	
	CREDITS_HEADER("Graphics")
	CREDITS_LINE("Landil (arrows and entities)")
	CREDITS_LINE("Apmox (logo and icon)")
	CREDITS_LINE("Bee (icons)")
	CREDITS_LINE("Sheep (entities)")
	CREDITS_LINE("Puch (clock)")
	
	CREDITS_HEADER("Sounds")
	CREDITS_LINE("Unreal Tournament")
	
	/*
		CREDITS_HEADER("Programmation support")
		CREDITS_LINE("LordSkelethom")
		CREDITS_LINE("heinrich5991")
		CREDITS_LINE("Vijfhoek")
	*/
	
	CREDITS_HEADER("Thanks to")
	CREDITS_LINE("The Teeworlds developers for 0.6.0")
	CREDITS_LINE("The whole community for their feedback and encouragements")	
}
